16.41. cdist-type__docker_compose(7) — cdist 6.9.4 documentation

# 16.41. cdist-type__docker_compose(7)

## 16.41.1. NAME

cdist-type__docker_compose - install docker-compose

## 16.41.2. DESCRIPTION

Installs docker-compose package. State 'absent' will not remove docker binary itself, only docker-compose binary will be removed

## 16.41.3. REQUIRED PARAMETERS

None.

## 16.41.4. OPTIONAL PARAMETERS

version

  Define docker_compose version, defaults to "1.9.0"

state

  'present' or 'absent', defaults to 'present'

## 16.41.5. BOOLEAN PARAMETERS

None.

## 16.41.6. EXAMPLES

    # Install docker-compose
    __docker_compose

    # Install version 1.9.0-rc4
    __docker_compose --version 1.9.0-rc4

    # Remove docker-compose
    __docker_compose --state absent

## 16.41.7. AUTHORS

Dominique Roux <dominique.roux--@--ungleich.ch>

## 16.41.8. COPYING

Copyright (C) 2016 Dominique Roux. Free use of this software is granted under the terms of the GNU General Public License version 3 or later (GPLv3+).